:orphan:

The new Abjad cookbook
======================

..  toctree::
    :maxdepth: 1
    :numbered:

    mapping_patterns_to_notation
    selecting_musical_objects
    splitting_and_fusing
    swapping_objects
    creating_tables_of_chords
    interpolating_between_chords
    creating_custom_symbols
    spacing_music_proportionally
    creating_floating_time_signatures
    creating_annotation_aware_spanners
    typesetting_parametric_staves
    creating_complex_rhythms
    modeling_texture_music
    creating_texture_music
    creating_fragmented_scores
    setting_up_a_new_score_project
    working_with_score_templates
    working_with_stylesheets
    preparing_complex_documents
    templating_and_persisting
    analyzing_audio
    outputting_midi
    creating_graphs

The old Abjad cookbook
======================

..  toctree::
    :maxdepth: 1
    :numbered:

    changing_notes_to_rests
    creating_rest_delimited_slurs
    mapping_lists_to_rhythms
    working_with_lists_of_numbers
    overriding_lilypond_grobs
